@@ -30,7 +30,7 @@ def set_logger_level(logger:logging.Logger,log_level:str):
         str
     """
 
-    level_mapping = [('info',logging.info),('debug',logging.debug),('error',logging.error)]
+    level_mapping = [('info',logging.INFO),('debug',logging.DEBUG),('error',logging.ERROR)]
 
     for level_name,level_value in level_mapping:
             if log_level == level_name:
